.. include:: ../common.rst



|Time90|

Two-dimensional (2D) Arrays
===========================

We have only worked with one-dimensional arrays so far, which have a single row of elements. But in the real world, data is often represented in a two-dimensional table with rows and columns. Programming languages can also represent arrays this way with multiple dimensions. A two-dimensional (2D) array has rows and columns. A 2D array in Java is actually an array of arrays.

.. toctree::
   :maxdepth: 3

   topic-8-1-2D-arrays-Day1.rst
   topic-8-1-2D-arrays-Day2.rst
